@@ -4,7 +4,7 @@ pub use musli_macros::Encode;
 /// Trait governing how types are encoded.
 pub trait Encode {
     /// Encode the given output.
-    fn encode<E>(&self, encoder: E) -> Result<(), E::Error>
+    fn encode<E>(&self, encoder: E) -> Result<E::Ok, E::Error>
     where
         E: Encoder;
 }
@@ -14,7 +14,7 @@ where
     T: ?Sized + Encode,
 {
     #[inline]
-    fn encode<E>(&self, encoder: E) -> Result<(), E::Error>
+    fn encode<E>(&self, encoder: E) -> Result<E::Ok, E::Error>
     where
         E: Encoder,
     {
@@ -27,7 +27,7 @@ where
     T: ?Sized + Encode,
 {
     #[inline]
-    fn encode<E>(&self, encoder: E) -> Result<(), E::Error>
+    fn encode<E>(&self, encoder: E) -> Result<E::Ok, E::Error>
     where
         E: Encoder,
     {
