@@ -4,7 +4,7 @@
 use core::{fmt, marker};
 
 use crate::de::{Decoder, PackDecoder, PairDecoder, PairsDecoder, SequenceDecoder};
-use crate::en::{Encoder, PackEncoder, PairEncoder, PairsEncoder, SequenceEncoder};
+use crate::en::{Encoder, PairEncoder, PairsEncoder, SequenceEncoder};
 
 enum NeverMarker {}
 
@@ -177,28 +177,6 @@ where
     }
 }
 
-impl<T> PackEncoder for Never<T>
-where
-    T: Encoder,
-{
-    type Ok = T::Ok;
-    type Error = T::Error;
-
-    type Encoder<'this> = Self
-    where
-        Self: 'this;
-
-    #[inline]
-    fn next(&mut self) -> Result<Self::Encoder<'_>, Self::Error> {
-        match self._never {}
-    }
-
-    #[inline]
-    fn end(self) -> Result<Self::Ok, Self::Error> {
-        match self._never {}
-    }
-}
-
 impl<T> SequenceEncoder for Never<T>
 where
     T: Encoder,
